<?php

namespace Strig\Category\Middleware;

use Ep\Middleware\BaseUrl;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Strig\Category\Repository\CategoryRepository;
use Laminas\Diactoros\Response\JsonResponse;

class CategorySpritesMiddleware implements MiddlewareInterface
{

    protected $repository;

    public function __construct(CategoryRepository $categoryRepository)
    {
        $this->repository = $categoryRepository;
    }


    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     * @throws \Psr\Cache\InvalidArgumentException
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        $baseUri = (string) $request->getAttribute(BaseUrl::BASE_URL);
        $uri = $request->getUri();
        $path = substr($uri->getPath(), 1);

        $pieces = explode('/', $path);

        list($categories, $dimensions) = $pieces;
        $categories = explode(',', $categories);
        $dimensions = explode(',', $dimensions);

        sort($categories);
        sort($dimensions);

        $cacheKey = implode(',', $categories) . '-';
        $cacheKey .= implode(',', $dimensions);

        $data = $this->repository->getSprites($categories, $dimensions, $path, $baseUri, $cacheKey);

        return new JsonResponse($data);
    }
}
