<?php

namespace Strig\Category\Repository;

use Psr\Cache\CacheItemPoolInterface;
use Psr\Cache\CacheItemInterface;
use Strig\Category\Adapter\CategoryAdapterInterface;

class CategoryRepository implements RepositoryInterface
{
    /**
     * @var CategoryAdapterInterface $adapter
     * @var CacheItemPoolInterface $cache
     */
    protected $adapter;
    protected $cache;

    public function __construct(CategoryAdapterInterface $adapter, CacheItemPoolInterface $cache)
    {
        $this->adapter = $adapter;
        $this->cache = $cache;
    }

    /**
     * @return array
     */
    public function getAll()
    {
        return $this->adapter->getAll();
    }


    /**
     * @param $parent
     * @return array
     */
    public function getByParent($parent)
    {
        return $this->adapter->getByParent($parent);
    }

    /**
     * @param array $categories
     * @param array $dimensions
     * @param string $path
     * @param string $baseUri
     * @param string $cacheKey
     * @return mixed
     * @throws \Psr\Cache\InvalidArgumentException
     */
    public function getSprites(array $categories, array $dimensions, string $path, string $baseUri, string $cacheKey)
    {
        $cacheItem = $this->cache->getItem($cacheKey);
        if ($cacheItem->isHit()) {
            return $cacheItem->get();
        }

        $data = $this->adapter->getSprites($categories, $dimensions, $path, $baseUri);

//        $cacheItem->set($data);
//        $this->cache->save($cacheItem);

        return $data;
    }

    /**
     * @param array $categories
     * @param string $dimension
     * @param string $path
     * @param string $baseUri
     * @return mixed
     */
    public function getImages(array $categories, string $dimension, string $path, string $baseUri)
    {
        return $this->adapter->getImages($categories, $dimension, $path, $baseUri);
    }

    public function dropCache()
    {
        $this->cache->clear();
    }
}
